@@ -2,13 +2,16 @@
 # For details: https://github.com/gaogaotiantian/objprint/blob/master/NOTICE.txt
 
 
+import inspect
+import itertools
 import json
 import re
-from types import FunctionType
+from types import FunctionType, MethodType
 from .color_util import COLOR, set_color
 
 
 class _PrintConfig:
+    enable = True
     indent = 2
     depth = 100
     width = 80
@@ -17,6 +20,8 @@ class _PrintConfig:
     elements = -1
     exclude = []
     include = []
+    line_number = False
+    print_methods = False
     skip_recursion = True
     honor_existing = True
 
@@ -57,24 +62,35 @@ class ObjPrint:
         }
         self._sys_print = print
 
-    def objprint(self, *objs, file=None, format="string", **kwargs):
-        if format == "json":
-            for obj in objs:
-                self._sys_print(json.dumps(self.objjson(obj), **kwargs))
-        else:
-            # Force color with cfg as if color is not in cfg, objstr will default to False
-            cfg = self._configs.overwrite(**kwargs)
-            kwargs["color"] = cfg.color
-            for obj in objs:
-                self._sys_print(self.objstr(obj, **kwargs), file=file)
+    def __call__(self, *objs, file=None, format="string", **kwargs):
+        cfg = self._configs.overwrite(**kwargs)
+        if cfg.enable:
+            call_frame = inspect.currentframe().f_back
+            if format == "json":
+                for obj in objs:
+                    self._sys_print(json.dumps(self.objjson(obj), **kwargs))
+            else:
+                # Force color with cfg as if color is not in cfg, objstr will default to False
+                kwargs["color"] = cfg.color
+                for obj in objs:
+                    self._sys_print(self.objstr(obj, call_frame=call_frame, **kwargs), file=file)
 
-    def objstr(self, obj, **kwargs):
+        if len(objs) == 1:
+            return objs[0]
+        return objs
+
+    def objstr(self, obj, call_frame=None, **kwargs):
+        if call_frame is None:
+            call_frame = inspect.currentframe().f_back
         # If no color option is specified, don't use color
         if "color" not in kwargs:
             kwargs["color"] = False
         cfg = self._configs.overwrite(**kwargs)
         memo = set() if cfg.skip_recursion else None
-        return self._objstr(obj, memo, indent_level=0, cfg=cfg)
+        if cfg.line_number:
+            return self._get_line_number_str(call_frame, cfg=cfg) + self._objstr(obj, memo, indent_level=0, cfg=cfg)
+        else:
+            return self._objstr(obj, memo, indent_level=0, cfg=cfg)
 
     def _objstr(self, obj, memo, indent_level, cfg):
         # If it's builtin type, return it directly
@@ -150,6 +166,13 @@ class ObjPrint:
 
     def _get_custom_object_str(self, obj, memo, indent_level, cfg):
 
+        def _get_method_line(attr):
+            if cfg.color:
+                return f"{set_color('def', COLOR.MAGENTA)} "\
+                    f"{set_color(attr, COLOR.GREEN)}{inspect.signature(getattr(obj, attr))}"
+            else:
+                return f"def {attr}{inspect.signature(getattr(obj, attr))}"
+
         def _get_line(key):
             val = self._objstr(obj.__dict__[key], memo, indent_level + 1, cfg)
             if cfg.label and any(re.fullmatch(pattern, key) is not None for pattern in cfg.label):
@@ -159,29 +182,53 @@ class ObjPrint:
             else:
                 return f".{key} = {val}"
 
-        if hasattr(obj, "__dict__"):
-            keys = []
-            for key in obj.__dict__.keys():
-                if cfg.include:
-                    if not any((re.fullmatch(pattern, key) is not None for pattern in cfg.include)):
-                        continue
-                if cfg.exclude:
-                    if any((re.fullmatch(pattern, key) is not None for pattern in cfg.exclude)):
-                        continue
-                keys.append(key)
-
-            elems = (_get_line(key) for key in sorted(keys))
-        else:
+        if not hasattr(obj, "__dict__"):
             return str(obj)
 
+        keys = []
+        for key in obj.__dict__.keys():
+            if cfg.include:
+                if not any((re.fullmatch(pattern, key) is not None for pattern in cfg.include)):
+                    continue
+            if cfg.exclude:
+                if any((re.fullmatch(pattern, key) is not None for pattern in cfg.exclude)):
+                    continue
+            keys.append(key)
+
+        methods = []
+        if cfg.print_methods:
+            for attr in dir(obj):
+                if not attr.startswith("__"):
+                    # Ignore magic functions
+                    if isinstance(getattr(obj, attr), MethodType):
+                        methods.append(attr)
+
+        elems = itertools.chain(
+            (_get_method_line(attr) for attr in sorted(methods)),
+            (_get_line(key) for key in sorted(keys))
+        )
+
         return self._get_pack_str(elems, obj, indent_level, cfg)
 
+    def _get_line_number_str(self, curr_frame, cfg):
+        curr_code = curr_frame.f_code
+        if cfg.color:
+            return f"{set_color(curr_code.co_name, COLOR.GREEN)} ({curr_code.co_filename}:{curr_frame.f_lineno})\n"
+        else:
+            return f"{curr_code.co_name} ({curr_code.co_filename}:{curr_frame.f_lineno})\n"
+
+    def enable(self):
+        self.config(enable=True)
+
+    def disable(self):
+        self.config(enable=False)
+
     def config(self, **kwargs):
         self._configs.set(**kwargs)
 
     def install(self, name="op"):
         import builtins
-        builtins.__dict__[name] = self.objprint
+        builtins.__dict__[name] = self
 
     def add_indent(self, line, indent_level, cfg):
         if isinstance(line, str):
@@ -197,7 +244,7 @@ class ObjPrint:
             if cfg.color:
                 return set_color(f"<{obj_type.__name__} {hex(id(obj))}", COLOR.CYAN), set_color(">", COLOR.CYAN)
             else:
-                return f"<{obj_type.__name__}", ">"
+                return f"<{obj_type.__name__} {hex(id(obj))}", ">"
 
     def _get_ellipsis(self, obj, cfg):
         header, footer = self._get_header_footer(obj, cfg)
